@@ -1,15 +1,17 @@
 C Output from Public domain Ratfor, version 1.0
-      subroutine recurse(fy,xispd,tpm,nreps,epsilon,n,nstate,wrk,xlc, al
-     *pha,beta,gamma,xi,xisum)
+      subroutine recurse(fy,xispd,tpm,nreps,epsilon,lns,nstate,wrk,xlc, 
+     *alpha,beta,gamma,xi,xisum)
       implicit double precision(a-h,o-z)
-      dimension xispd(1), xlc(1)
+      dimension xispd(1), xlc(1), lns(1)
       dimension tpm(nstate,1), wrk(nstate,1)
       dimension fy(nstate,1), alpha(nstate,1), beta(nstate,1), gamma(nst
      *ate,1)
       dimension xi(nstate,nstate,1), xisum(nstate,1)
       zero = 0.d0
+      kstop = 0
       do23000 k = 1,nreps 
-      kstart = (k-1)*n + 1
+      n = lns(k)
+      kstart = 1 + kstop
       call afun(fy(1,kstart),xispd,tpm,epsilon,n,nstate,wrk, xlc(kstart)
      *,alpha(1,kstart))
       call bfun(fy(1,kstart),xispd,tpm,epsilon,n,nstate,wrk, beta(1,ksta
@@ -18,9 +20,10 @@ C Output from Public domain Ratfor, version 1.0
      *ma(1,kstart))
       call xfun(alpha(1,kstart),beta(1,kstart),fy(1,kstart), tpm,epsilon
      *,n,nstate,wrk,xi(1,1,kstart-k+1))
+      kstop = kstop + lns(k)
 23000 continue
 23001 continue
-      kstop = nreps*(n-1)
+      kstop = kstop - nreps
       do23002 i = 1,nstate 
       do23004 j = 1,nstate 
       xisum(i,j) = zero
